@@ -39,13 +39,13 @@ def parse_args(arg_list):
     main_parser = ArgumentParser(
         prog="rstats-reader",
         description="Displays statistics in RStats logfiles, with optional conversion",
-        epilog="Released under NPOSL-3.0, (C) 2016, 2019 Mischif",
+        epilog="Released under Prosperity 3.0.0, (C) 2016, 2019-20, 2022 Jeremy Brown",
     )
 
     main_parser.add_argument(
         "path",
         type=Path,
-        help="gzipped rstats logfile",
+        help="gzipped RStats logfile",
     )
 
     main_parser.add_argument(
